package com.gic.haoban.manage.api.util.notify;

import com.alibaba.fastjson.JSONObject;
import com.gic.commons.util.GICMQClientUtil;
import com.gic.haoban.manage.api.dto.notify.qdto.NoticeMessageQDTO;
import com.gic.haoban.manage.api.enums.NoticeMessageTypeEnum;
import com.gic.mq.sdk.GicMQClient;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;

import java.util.Map;

import static org.slf4j.LoggerFactory.getLogger;

/**
 * Created 2021/12/17.
 *
 * @author hua
 */
public class NoticeMessageUtil {

    private static final Logger logger = getLogger(NoticeMessageUtil.class);

    private static final String NOTICE_MESSAGE = "haobanNoticeMessage";

    /**
     * 发送消息
     *
     * @param enterpriseId 企业id
     * @param clerkId      执行人导购
     * @param messageType  消息类型 NoticeMessageTypeEnum
     * @param optTargetId 操作对象
     * @param fieldMap     解析模板的字段
     * @param extendField  拓展字段给前端使用 没有可以为null
     */
    public static void sendNoticeMessage(String enterpriseId, String clerkId, int messageType, String optTargetId, Map<String, String> fieldMap, Map<String, Object> extendField) {
        if (StringUtils.isAnyBlank(enterpriseId, clerkId)) {
            throw new RuntimeException("必传参数没传");
        }
        NoticeMessageTypeEnum messageTypeEnum = NoticeMessageTypeEnum.getByType(messageType);
        if (messageTypeEnum == null) {
            throw new RuntimeException("消息类型不存在");
        }
        NoticeMessageQDTO noticeMessageQDTO = new NoticeMessageQDTO();
        noticeMessageQDTO.setEnterpriseId(enterpriseId);
        noticeMessageQDTO.setClerkId(clerkId);
        noticeMessageQDTO.setMessageType(messageType);
        noticeMessageQDTO.setContentMap(fieldMap);
        noticeMessageQDTO.setExtendContent(extendField);
        noticeMessageQDTO.setOptTargetId(optTargetId);
        String ret = JSONObject.toJSONString(noticeMessageQDTO);
        logger.info("发送消息：{}", ret);
        GicMQClient clientInstance = GICMQClientUtil.getClientInstance();
        try {
            clientInstance.sendMessage(NOTICE_MESSAGE, ret);
        } catch (Exception e) {
            logger.info("发送消息异常：{}", e);
        }
    }
}
